@@ -8,7 +8,12 @@
 
 """Configuration for Invenio-Search-UI."""
 
-from __future__ import absolute_import, print_function
+from .views import SearchAppInvenioRestConfigHelper
+
+SEARCH_UI_SEARCH_TEMPLATE = 'invenio_search_ui/search.html'
+"""Configure the search page template."""
+
+# The configuration below is for the AngularJS search app configuration
 
 SEARCH_UI_SEARCH_API = '/api/records/'
 """Configure the search engine endpoint."""
@@ -16,8 +21,7 @@ SEARCH_UI_SEARCH_API = '/api/records/'
 SEARCH_UI_SEARCH_INDEX = 'records'
 """Name of the search index used."""
 
-SEARCH_UI_SEARCH_TEMPLATE = 'invenio_search_ui/search.html'
-"""Configure the search page template."""
+# The configuration below is for the AngularJS search app templates
 
 SEARCH_UI_JSTEMPLATE_COUNT = 'templates/invenio_search_ui/count.html'
 """Configure the count template."""
@@ -43,8 +47,7 @@ SEARCH_UI_JSTEMPLATE_LOADING = 'templates/invenio_search_ui/loading.html'
 SEARCH_UI_JSTEMPLATE_PAGINATION = 'templates/invenio_search_ui/pagination.html'
 """Configure the pagination template."""
 
-SEARCH_UI_JSTEMPLATE_RESULTS = \
-    'templates/invenio_search_ui/marc21/default.html'
+SEARCH_UI_JSTEMPLATE_RESULTS = 'templates/invenio_search_ui/results.html'
 """Configure the results template."""
 
 SEARCH_UI_JSTEMPLATE_SELECT_BOX = 'templates/invenio_search_ui/selectbox.html'
@@ -53,3 +56,8 @@ SEARCH_UI_JSTEMPLATE_SELECT_BOX = 'templates/invenio_search_ui/selectbox.html'
 SEARCH_UI_JSTEMPLATE_SORT_ORDER = \
     'templates/invenio_search_ui/togglebutton.html'
 """Configure the toggle button template."""
+
+SEARCH_UI_SEARCH_CONFIG_GEN = {
+    'invenio_records_rest': SearchAppInvenioRestConfigHelper,
+}
+"""Override the Invenio-Search-JS config generator."""
